pcre: Perl-compatible regular expressions library
=================================================

Description
-----------

Perl-compatible regular expressions library.

License
-------

BSD License; see LICENCE (sic) at the root of the original tarball.


Upstream Contact
----------------

Mailing list at https://lists.exim.org/mailman/listinfo/pcre-dev

Dependencies
------------

None listed.


Special Update/Build Instructions
---------------------------------

None applicable (see README at tarball's root).
